# PythonDebugTools

*Pull requests and sugestions are welcome.*

## Getting Started

Helper tools to ease development.

### Tkinter 
All named colors in tkinter can be found in [colors.png](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/colors.png)

All custom colors in tkinter can be found in [colors.py](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/colors.py)

All themes in tkinter can be found in [TkinterThemes.jpg](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/TkinterThemes.jpg)


### Debug 

[console.py](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/console.py) has functions to format an object to the console, allowing for easier debug.

[converters.py](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/converters.py) has functions to convert any object to a dict.

[decorators.py](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/decorators.py) has functions to be used as decorators to make debug more efficent. 

[chains.py](https://github.com/Jakar510/PythonDebugTools/tree/master/src/PythonDebugTools/chains.py) has functions to be used as decorators, in certain cases, to make debug more efficent. 

 


## Installing

using pip3 or pip,

pip3 install PythonDebugTools 

## Contributing

Please read [CONTRIBUTING.md](https://github.com/Jakar510/PythonDebugTools/tree/master/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.

## Authors

* **Tyler Stegmaier** - *Initial work* - [Jakar510](https://github.com/Jakar510)

See also the list of [contributors](https://github.com/Jakar510/PythonDebugTools/blob/master/contributors.md) who participated in this project.

## License

This project is licensed under the GNU GENERAL PUBLIC LICENSE - see the [LICENSE.md](https://github.com/Jakar510/PythonDebugTools/blob/master/LICENSE) file for details

## Acknowledgments

* [StackOverFlow Answer](https://stackoverflow.com/a/31485450/9530917)
